about summary refs log tree commit diff
path: root/src/comp/metadata
diff options
context:
space:
mode:
authorPatrick Walton <pcwalton@mimiga.net>2012-01-19 14:24:03 -0800
committerPatrick Walton <pcwalton@mimiga.net>2012-01-19 14:24:03 -0800
commitbdb8f6cf52a2a4e2f78e6fa95d42140aa26ec31c (patch)
tree0d0b55cfc904eeec0d4bf99bd92744ff81324b39 /src/comp/metadata
parente6a7383a5f478b90b95556da25160ffee870b57d (diff)
downloadrust-bdb8f6cf52a2a4e2f78e6fa95d42140aa26ec31c.tar.gz
rust-bdb8f6cf52a2a4e2f78e6fa95d42140aa26ec31c.zip
rustc: "tag" -> "enum"
Diffstat (limited to 'src/comp/metadata')
-rw-r--r--src/comp/metadata/common.rs2
-rw-r--r--src/comp/metadata/cstore.rs4
-rw-r--r--src/comp/metadata/decoder.rs4
-rw-r--r--src/comp/metadata/tyencode.rs2
4 files changed, 6 insertions, 6 deletions
diff --git a/src/comp/metadata/common.rs b/src/comp/metadata/common.rs
index b16120d1bec..c4ca48d6b3e 100644
--- a/src/comp/metadata/common.rs
+++ b/src/comp/metadata/common.rs
@@ -1,4 +1,4 @@
-// EBML tag definitions and utils shared by the encoder and decoder
+// EBML enum definitions and utils shared by the encoder and decoder
 
 import str;
 
diff --git a/src/comp/metadata/decoder.rs b/src/comp/metadata/decoder.rs
index e3790e4b09b..6b573de4c50 100644
--- a/src/comp/metadata/decoder.rs
+++ b/src/comp/metadata/decoder.rs
@@ -252,7 +252,7 @@ fn get_tag_variants(cdata: cmd, id: ast::node_id, tcx: ty::ctxt)
           ty::ty_fn(f) {
             for a: ty::arg in f.inputs { arg_tys += [a.ty]; }
           }
-          _ { /* Nullary tag variant. */ }
+          _ { /* Nullary enum variant. */ }
         }
         alt variant_disr_val(item) {
           some(val) { disr_val = val; }
@@ -347,7 +347,7 @@ fn item_family_to_str(fam: u8) -> str {
       't' { ret "type"; }
       'm' { ret "mod"; }
       'n' { ret "native mod"; }
-      'v' { ret "tag"; }
+      'v' { ret "enum"; }
       'i' { ret "impl"; }
       'I' { ret "iface"; }
     }
diff --git a/src/comp/metadata/tyencode.rs b/src/comp/metadata/tyencode.rs
index d4c562b67f9..539d3fad079 100644
--- a/src/comp/metadata/tyencode.rs
+++ b/src/comp/metadata/tyencode.rs
@@ -25,7 +25,7 @@ type ctxt =
 // Whatever format you choose should not contain pipe characters.
 type ty_abbrev = {pos: uint, len: uint, s: @str};
 
-tag abbrev_ctxt { ac_no_abbrevs; ac_use_abbrevs(hashmap<ty::t, ty_abbrev>); }
+enum abbrev_ctxt { ac_no_abbrevs; ac_use_abbrevs(hashmap<ty::t, ty_abbrev>); }
 
 fn cx_uses_abbrevs(cx: @ctxt) -> bool {
     alt cx.abbrevs {
diff --git a/src/comp/metadata/cstore.rs b/src/comp/metadata/cstore.rs
index de56aa236f5..6fb9ac4edb4 100644
--- a/src/comp/metadata/cstore.rs
+++ b/src/comp/metadata/cstore.rs
@@ -36,11 +36,11 @@ type crate_metadata = @{name: str,
                         cnum: ast::crate_num};
 
 // This is a bit of an experiment at encapsulating the data in cstore. By
 // keeping all the data in a non-exported tag variant, it's impossible for
 // other modules to access the cstore's private data. This could also be
 // achieved with an obj, but at the expense of a vtable. Not sure if this is a
 // good pattern or not.
-tag cstore { private(cstore_private); }
+enum cstore { private(cstore_private); }
 
 type cstore_private =
     @{metas: map::hashmap<ast::crate_num, crate_metadata>,
@@ -36,11 +36,11 @@ type crate_metadata = @{name: str,
 
 // This is a bit of an experiment at encapsulating the data in cstore. By
-// keeping all the data in a non-exported tag variant, it's impossible for
+// keeping all the data in a non-exported enum variant, it's impossible for
 // other modules to access the cstore's private data. This could also be
 // achieved with an obj, but at the expense of a vtable. Not sure if this is a